@@ -28,6 +28,14 @@ class Psr18ClientTest extends TestCase
         TestHttpServer::start();
     }
 
+    public static function tearDownAfterClass(): void
+    {
+        TestHttpServer::stop();
+    }
+
+    /**
+     * @requires function ob_gzhandler
+     */
     public function testSendRequest()
     {
         $factory = new Psr17Factory();
