@@ -36,6 +36,7 @@ return [
         'bem' => 'бемба тілі',
         'bez' => 'бена тілі',
         'bg' => 'болгар тілі',
+        'bgc' => 'хариани тілі',
         'bgn' => 'батыс балучи тілі',
         'bho' => 'бходжпури тілі',
         'bi' => 'бислама тілі',
@@ -213,6 +214,7 @@ return [
         'lij' => 'лигур тілі',
         'lil' => 'лиллуэт тілі',
         'lkt' => 'лакота тілі',
+        'lmo' => 'Ломбард',
         'ln' => 'лингала тілі',
         'lo' => 'лаос тілі',
         'lou' => 'креоль тілі (Луизиана)',
@@ -292,6 +294,7 @@ return [
         'om' => 'оромо тілі',
         'or' => 'ория тілі',
         'os' => 'осетин тілі',
+        'osa' => 'осейдж тілі',
         'pa' => 'пенджаб тілі',
         'pag' => 'пангасинан тілі',
         'pam' => 'пампанга тілі',
@@ -306,6 +309,7 @@ return [
         'pt' => 'португал тілі',
         'qu' => 'кечуа тілі',
         'quc' => 'киче тілі',
+        'raj' => 'раджастани тілі',
         'rap' => 'рапануй тілі',
         'rar' => 'раротонган тілі',
         'rhg' => 'рохинджа',
@@ -430,7 +434,6 @@ return [
         'ar_001' => 'қазіргі стандартты араб тілі',
         'de_CH' => 'швейцариялық әдеби неміс тілі',
         'fa_AF' => 'дари тілі',
-        'hi_Latn' => 'Хинди (латын жазуы)',
         'nds_NL' => 'төменгі саксон тілі',
         'nl_BE' => 'фламанд тілі',
         'pt_BR' => 'бразилиялық португал тілі',
