@@ -2,11 +2,16 @@
 
 return [
     'Names' => [
+        'Adlm' => 'Adlam',
         'Arab' => 'Arabies',
+        'Aran' => 'Nastaliq',
         'Armn' => 'Armeens',
         'Beng' => 'Bengaals',
         'Bopo' => 'Bopomofo',
         'Brai' => 'Braille',
+        'Cakm' => 'Chakma',
+        'Cans' => 'Verenigde Kanadese Inheemse Lettergreepskrif',
+        'Cher' => 'Cherokee',
         'Cyrl' => 'Sirillies',
         'Deva' => 'Devanagari',
         'Ethi' => 'Etiopies',
@@ -32,14 +37,23 @@ return [
         'Latn' => 'Latyn',
         'Mlym' => 'Malabaars',
         'Mong' => 'Mongools',
+        'Mtei' => 'Meitei-Majek',
         'Mymr' => 'Mianmar',
+        'Nkoo' => 'N’Ko',
+        'Olck' => 'Ol Chiki',
         'Orya' => 'Oriya',
+        'Rohg' => 'Hanifi',
         'Sinh' => 'Sinhala',
+        'Sund' => 'Soendanees',
+        'Syrc' => 'Siries',
         'Taml' => 'Tamil',
         'Telu' => 'Teloegoe',
+        'Tfng' => 'Tifinagh',
         'Thaa' => 'Thaana',
         'Thai' => 'Thai',
         'Tibt' => 'Tibettaans',
+        'Vaii' => 'Vai',
+        'Yiii' => 'Yi',
         'Zmth' => 'Wiskundige notasie',
         'Zsye' => 'Emoji',
         'Zsym' => 'Simbole',
