@@ -156,15 +156,13 @@ return [
         'America/Montserrat' => 'Atlantik wagty (Monserrat)',
         'America/Nassau' => 'Demirgazyk Amerika gündogar wagty (Nassau)',
         'America/New_York' => 'Demirgazyk Amerika gündogar wagty (Nýu-Ýork)',
-        'America/Nipigon' => 'Demirgazyk Amerika gündogar wagty (Nipigon)',
         'America/Nome' => 'Alýaska wagty (Nom)',
         'America/Noronha' => 'Fernandu-di-Noronýa wagty (Noronha)',
         'America/North_Dakota/Beulah' => 'Merkezi Amerika (Boýla, Demirgazyk Dakota)',
         'America/North_Dakota/Center' => 'Merkezi Amerika (Sentr, Demirgazyk Dakota)',
-        'America/North_Dakota/New_Salem' => 'Merkezi Amerika (Nýu-Salem, D.g. Dakota)',
+        'America/North_Dakota/New_Salem' => 'Merkezi Amerika (Nýu-Salem, Demirgazyk Dakota)',
         'America/Ojinaga' => 'Merkezi Amerika (Ohinaga)',
         'America/Panama' => 'Demirgazyk Amerika gündogar wagty (Panama)',
-        'America/Pangnirtung' => 'Demirgazyk Amerika gündogar wagty (Pangnirtang)',
         'America/Paramaribo' => 'Surinam wagty (Paramaribo)',
         'America/Phoenix' => 'Demirgazyk Amerika dag wagty (Feniks)',
         'America/Port-au-Prince' => 'Demirgazyk Amerika gündogar wagty (Port-o-Prens)',
@@ -172,13 +170,11 @@ return [
         'America/Porto_Velho' => 'Amazon wagty (Portu-Welýu)',
         'America/Puerto_Rico' => 'Atlantik wagty (Puerto-Riko)',
         'America/Punta_Arenas' => 'Çili wagty (Punta-Arenas)',
-        'America/Rainy_River' => 'Merkezi Amerika (Reýni-Riwer)',
         'America/Rankin_Inlet' => 'Merkezi Amerika (Rankin-Inlet)',
         'America/Recife' => 'Braziliýa wagty (Resifi)',
         'America/Regina' => 'Merkezi Amerika (Rejaýna)',
         'America/Resolute' => 'Merkezi Amerika (Rezolýut)',
         'America/Rio_Branco' => 'Braziliýa wagty (Riu-Branku)',
-        'America/Santa_Isabel' => 'Demirgazyk-günbatar Meksika wagty (Santa-Izabel)',
         'America/Santarem' => 'Braziliýa wagty (Santarem)',
         'America/Santiago' => 'Çili wagty (Santýago)',
         'America/Santo_Domingo' => 'Atlantik wagty (Santo-Domingo)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'Merkezi Amerika (Swift-Karent)',
         'America/Tegucigalpa' => 'Merkezi Amerika (Tegusigalpa)',
         'America/Thule' => 'Atlantik wagty (Tule)',
-        'America/Thunder_Bay' => 'Demirgazyk Amerika gündogar wagty (Tander-Beý)',
         'America/Tijuana' => 'Demirgazyk Amerika Ýuwaş umman wagty (Tihuana)',
         'America/Toronto' => 'Demirgazyk Amerika gündogar wagty (Toronto)',
         'America/Tortola' => 'Atlantik wagty (Tortola)',
@@ -202,7 +197,6 @@ return [
         'America/Whitehorse' => 'Ýukon wagty (Waýthors)',
         'America/Winnipeg' => 'Merkezi Amerika (Winnipeg)',
         'America/Yakutat' => 'Alýaska wagty (Ýakutat)',
-        'America/Yellowknife' => 'Demirgazyk Amerika dag wagty (Ýellounaýf)',
         'Antarctica/Casey' => 'Antarktika wagty (Keýsi)',
         'Antarctica/Davis' => 'Deýwis wagty',
         'Antarctica/DumontDUrville' => 'Dýumon-d-Ýurwil wagty',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'Merkezi Awstraliýa wagty (Adelaida)',
         'Australia/Brisbane' => 'Gündogar Awstraliýa wagty (Brisben)',
         'Australia/Broken_Hill' => 'Merkezi Awstraliýa wagty (Broken-Hil)',
-        'Australia/Currie' => 'Gündogar Awstraliýa wagty (Kerri)',
         'Australia/Darwin' => 'Merkezi Awstraliýa wagty (Darwin)',
         'Australia/Eucla' => 'Merkezi Awstraliýa günbatar wagty (Ýukla)',
         'Australia/Hobart' => 'Gündogar Awstraliýa wagty (Hobart)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'Gündogar Ýewropa wagty (Tallin)',
         'Europe/Tirane' => 'Merkezi Ýewropa wagty (Tirana)',
         'Europe/Ulyanovsk' => 'Moskwa wagty (Ulýanowsk)',
-        'Europe/Uzhgorod' => 'Gündogar Ýewropa wagty (Užgorod)',
         'Europe/Vaduz' => 'Merkezi Ýewropa wagty (Waduz)',
         'Europe/Vatican' => 'Merkezi Ýewropa wagty (Watikan)',
         'Europe/Vienna' => 'Merkezi Ýewropa wagty (Wena)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'Wolgograd wagty',
         'Europe/Warsaw' => 'Merkezi Ýewropa wagty (Warşawa)',
         'Europe/Zagreb' => 'Merkezi Ýewropa wagty (Zagreb)',
-        'Europe/Zaporozhye' => 'Gündogar Ýewropa wagty (Zaporožýe)',
         'Europe/Zurich' => 'Merkezi Ýewropa wagty (Sýurih)',
         'Indian/Antananarivo' => 'Gündogar Afrika wagty (Antananariwu)',
         'Indian/Chagos' => 'Hindi ummany wagty (Çagos)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'Solomon adalary wagty (Gwadalkanal)',
         'Pacific/Guam' => 'Çamorro wagty (Guam)',
         'Pacific/Honolulu' => 'Gawaý-Aleut wagty (Gonolulu)',
-        'Pacific/Johnston' => 'Gawaý-Aleut wagty (Jonston)',
         'Pacific/Kiritimati' => 'Laýn adalary wagty (Kiritimati)',
         'Pacific/Kosrae' => 'Kosraýe wagty',
         'Pacific/Kwajalein' => 'Marşall adalary wagty (Kwajaleýn)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'Weýk adasy wagty',
         'Pacific/Wallis' => 'Uollis we Futuna wagty',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
