@@ -11,6 +11,7 @@
 
 namespace Symfony\Component\Messenger\Tests\Middleware;
 
+use PHPUnit\Framework\AssertionFailedError;
 use PHPUnit\Framework\Constraint\Callback;
 use PHPUnit\Framework\MockObject\Stub\ReturnCallback;
 use PHPUnit\Framework\TestCase;
@@ -67,12 +68,7 @@ class DispatchAfterCurrentBusMiddlewareTest extends TestCase
             ->with($this->callback(function (Envelope $envelope) use (&$series) {
                 return $envelope->getMessage() === array_shift($series);
             }))
-            ->willReturnOnConsecutiveCalls(
-                $this->willHandleMessage(),
-                $this->willHandleMessage(),
-                $this->willHandleMessage(),
-                $this->willHandleMessage()
-            );
+            ->will($this->willHandleMessage());
 
         $messageBus->dispatch($message);
     }
@@ -110,16 +106,19 @@ class DispatchAfterCurrentBusMiddlewareTest extends TestCase
             $secondEvent,
         ];
 
-        $handlingMiddleware->expects($this->exactly(3))
+        $matcher = $this->exactly(3);
+        $handlingMiddleware->expects($matcher)
             ->method('handle')
             ->with($this->callback(function (Envelope $envelope) use (&$series) {
                 return $envelope->getMessage() === array_shift($series);
             }))
-            ->willReturnOnConsecutiveCalls(
-                $this->willHandleMessage(),
-                $this->throwException(new \RuntimeException('Some exception while handling first event')),
-                $this->willHandleMessage()
-            );
+            ->willReturnCallback(function ($envelope, StackInterface $stack) use ($matcher) {
+                if (2 === $matcher->getInvocationCount()) {
+                    throw new \RuntimeException('Some exception while handling first event');
+                }
+
+                return $stack->next()->handle($envelope, $stack);
+            });
 
         $this->expectException(DelayedMessageHandlingException::class);
         $this->expectExceptionMessage('RuntimeException: Some exception while handling first event');
@@ -176,34 +175,39 @@ class DispatchAfterCurrentBusMiddlewareTest extends TestCase
             // Note: $eventL3a should not be handled.
         ];
 
-        $handlingMiddleware->expects($this->exactly(7))
+        $matcher = $this->exactly(7);
+        $handlingMiddleware->expects($matcher)
             ->method('handle')
             ->with($this->callback(function (Envelope $envelope) use (&$series) {
                 return $envelope->getMessage() === array_shift($series);
             }))
-            ->willReturnOnConsecutiveCalls(
-                $this->willHandleMessage(),
-                $this->willHandleMessage(),
-                $this->returnCallback(function ($envelope, StackInterface $stack) use ($eventBus, $eventL2a, $eventL2b) {
-                    $envelope1 = new Envelope($eventL2a, [new DispatchAfterCurrentBusStamp()]);
-                    $eventBus->dispatch($envelope1);
-                    $eventBus->dispatch(new Envelope($eventL2b, [new DispatchAfterCurrentBusStamp()]));
+            ->willReturnCallback(function ($envelope, StackInterface $stack) use ($eventBus, $eventL2a, $eventL2b, $eventL3a, $eventL3b, $matcher) {
+                switch ($matcher->getInvocationCount()) {
+                    case 1:
+                    case 2:
+                    case 4:
+                    case 7:
+                        return $stack->next()->handle($envelope, $stack);
 
-                    return $stack->next()->handle($envelope, $stack);
-                }),
-                $this->willHandleMessage(),
-                $this->returnCallback(function () use ($eventBus, $eventL3a) {
-                    $eventBus->dispatch(new Envelope($eventL3a, [new DispatchAfterCurrentBusStamp()]));
+                    case 3:
+                        $envelope1 = new Envelope($eventL2a, [new DispatchAfterCurrentBusStamp()]);
+                        $eventBus->dispatch($envelope1);
+                        $eventBus->dispatch(new Envelope($eventL2b, [new DispatchAfterCurrentBusStamp()]));
 
-                    throw new \RuntimeException('Some exception while handling Event level 2a');
-                }),
-                $this->returnCallback(function ($envelope, StackInterface $stack) use ($eventBus, $eventL3b) {
-                    $eventBus->dispatch(new Envelope($eventL3b, [new DispatchAfterCurrentBusStamp()]));
+                        return $stack->next()->handle($envelope, $stack);
 
-                    return $stack->next()->handle($envelope, $stack);
-                }),
-                $this->willHandleMessage()
-            );
+                    case 5:
+                        $eventBus->dispatch(new Envelope($eventL3a, [new DispatchAfterCurrentBusStamp()]));
+
+                        throw new \RuntimeException('Some exception while handling Event level 2a');
+                    case 6:
+                        $eventBus->dispatch(new Envelope($eventL3b, [new DispatchAfterCurrentBusStamp()]));
+
+                        return $stack->next()->handle($envelope, $stack);
+                }
+
+                throw new AssertionFailedError('Unexpected call to handle');
+            });
 
         $this->expectException(DelayedMessageHandlingException::class);
         $this->expectExceptionMessage('RuntimeException: Some exception while handling Event level 2a');
