@@ -48,6 +48,7 @@ class ReflectionExtractorTest extends TestCase
                 'bal',
                 'parent',
                 'collection',
+                'collectionAsObject',
                 'nestedCollection',
                 'mixedCollection',
                 'B',
@@ -68,6 +69,7 @@ class ReflectionExtractorTest extends TestCase
                 'arrayOfMixed',
                 'listOfStrings',
                 'parentAnnotation',
+                'genericInterface',
                 'foo',
                 'foo2',
                 'foo3',
@@ -112,6 +114,7 @@ class ReflectionExtractorTest extends TestCase
                 'bal',
                 'parent',
                 'collection',
+                'collectionAsObject',
                 'nestedCollection',
                 'mixedCollection',
                 'B',
@@ -132,6 +135,7 @@ class ReflectionExtractorTest extends TestCase
                 'arrayOfMixed',
                 'listOfStrings',
                 'parentAnnotation',
+                'genericInterface',
                 'foo',
                 'foo2',
                 'foo3',
@@ -165,6 +169,7 @@ class ReflectionExtractorTest extends TestCase
                 'bal',
                 'parent',
                 'collection',
+                'collectionAsObject',
                 'nestedCollection',
                 'mixedCollection',
                 'B',
@@ -185,6 +190,7 @@ class ReflectionExtractorTest extends TestCase
                 'arrayOfMixed',
                 'listOfStrings',
                 'parentAnnotation',
+                'genericInterface',
                 'foo',
                 'foo2',
                 'foo3',
@@ -517,6 +523,7 @@ class ReflectionExtractorTest extends TestCase
         $this->assertEquals([new Type(Type::BUILTIN_TYPE_ARRAY, false, null, true, new Type(Type::BUILTIN_TYPE_INT), new Type(Type::BUILTIN_TYPE_STRING))], $this->extractor->getTypes(Php74Dummy::class, 'stringCollection'));
         $this->assertEquals([new Type(Type::BUILTIN_TYPE_INT, true)], $this->extractor->getTypes(Php74Dummy::class, 'nullableWithDefault'));
         $this->assertEquals([new Type(Type::BUILTIN_TYPE_ARRAY, false, null, true)], $this->extractor->getTypes(Php74Dummy::class, 'collection'));
+        $this->assertEquals([new Type(Type::BUILTIN_TYPE_ARRAY, true, null, true, new Type(Type::BUILTIN_TYPE_INT), new Type(Type::BUILTIN_TYPE_OBJECT, false, Dummy::class))], $this->extractor->getTypes(Php74Dummy::class, 'nullableTypedCollection'));
     }
 
     /**
