@@ -46,6 +46,11 @@ class Dummy extends ParentDummy
     #[Groups(['a', 'b'])]
     public $collection;
 
+    /**
+     * @var DummyCollection<int, string>
+     */
+    public $collectionAsObject;
+
     /**
      * @var string[][]
      */
@@ -165,6 +170,11 @@ class Dummy extends ParentDummy
      */
     public $parentAnnotation;
 
+    /**
+     * @var \BackedEnum<string>
+     */
+    public $genericInterface;
+
     public static function getStatic()
     {
     }
