@@ -307,8 +307,11 @@ class ContextListenerTest extends TestCase
 
     public function testSessionIsNotReported()
     {
-        $usageReporter = $this->getMockBuilder(\stdClass::class)->addMethods(['__invoke'])->getMock();
-        $usageReporter->expects($this->never())->method('__invoke');
+        $this->expectNotToPerformAssertions();
+
+        $usageReporter = static function (): void {
+            throw new \LogicException('This should not be called');
+        };
 
         $session = new Session(new MockArraySessionStorage(), null, null, $usageReporter);
 
