@@ -420,10 +420,10 @@ class AbstractObjectNormalizerTest extends TestCase
     {
         $extractor = $this->createMock(PhpDocExtractor::class);
         $extractor->method('getTypes')
-            ->will($this->onConsecutiveCalls(
+            ->willReturn(
                 [new Type('array', false, null, true, new Type('int'), new Type('object', false, DummyChild::class))],
                 null
-            ));
+            );
 
         $denormalizer = new AbstractObjectNormalizerCollectionDummy(null, null, $extractor);
         $arrayDenormalizer = new ArrayDenormalizerDummy();
@@ -475,10 +475,10 @@ class AbstractObjectNormalizerTest extends TestCase
     {
         $extractor = $this->createMock(PhpDocExtractor::class);
         $extractor->method('getTypes')
-            ->will($this->onConsecutiveCalls(
+            ->willReturn(
                 [new Type('array', false, null, true, new Type('int'), new Type('string'))],
                 null
-            ));
+            );
 
         $denormalizer = new AbstractObjectNormalizerCollectionDummy(null, null, $extractor);
         $arrayDenormalizer = new ArrayDenormalizerDummy();
@@ -662,7 +662,7 @@ class AbstractObjectNormalizerTest extends TestCase
     {
         $extractor = $this->createMock(PhpDocExtractor::class);
         $extractor->method('getTypes')
-            ->will($this->onConsecutiveCalls(
+            ->willReturn(
                 [new Type('bool')],
                 [new Type('bool')],
                 [new Type('bool')],
@@ -675,7 +675,7 @@ class AbstractObjectNormalizerTest extends TestCase
                 [new Type('float')],
                 [new Type('float')],
                 [new Type('float')]
-            ));
+            );
 
         $denormalizer = new AbstractObjectNormalizerCollectionDummy(null, null, $extractor);
         $arrayDenormalizer = new ArrayDenormalizerDummy();
@@ -888,6 +888,7 @@ class AbstractObjectNormalizerTest extends TestCase
     public function testDenormalizeUntypedFormatNotNormalizable()
     {
         $this->expectException(NotNormalizableValueException::class);
+        $this->expectExceptionMessage('Custom exception message');
         $serializer = new Serializer([new CustomNormalizer(), new ObjectNormalizer(null, null, null, new PropertyInfoExtractor([], [new PhpDocExtractor(), new ReflectionExtractor()]))]);
         $serializer->denormalize(['value' => 'test'], DummyWithNotNormalizable::class, 'xml');
     }
@@ -1028,8 +1029,7 @@ class AbstractObjectNormalizerTest extends TestCase
 
     public function testDenormalizeXmlScalar()
     {
-        $normalizer = new class () extends AbstractObjectNormalizer
-        {
+        $normalizer = new class() extends AbstractObjectNormalizer {
             public function __construct()
             {
                 parent::__construct(null, new MetadataAwareNameConverter(new ClassMetadataFactory(new AttributeLoader())));
@@ -1067,6 +1067,26 @@ class AbstractObjectNormalizerTest extends TestCase
 
         $this->assertSame(['string' => 'yes'], $normalized);
     }
+
+    /**
+     * @dataProvider provideBooleanTypesData
+     */
+    public function testDenormalizeBooleanTypesWithNotMatchingData(array $data, string $type)
+    {
+        $normalizer = new AbstractObjectNormalizerWithMetadataAndPropertyTypeExtractors();
+
+        $this->expectException(NotNormalizableValueException::class);
+
+        $normalizer->denormalize($data, $type);
+    }
+
+    public function provideBooleanTypesData()
+    {
+        return [
+            [['foo' => true], FalsePropertyDummy::class],
+            [['foo' => false], TruePropertyDummy::class],
+        ];
+    }
 }
 
 class AbstractObjectNormalizerDummy extends AbstractObjectNormalizer
@@ -1335,6 +1355,18 @@ class XmlScalarDummy
     public $value;
 }
 
+class FalsePropertyDummy
+{
+    /** @var false */
+    public $foo;
+}
+
+class TruePropertyDummy
+{
+    /** @var true */
+    public $foo;
+}
+
 class SerializerCollectionDummy implements SerializerInterface, DenormalizerInterface
 {
     private array $normalizers;
@@ -1478,3 +1510,33 @@ class DummyWithEnumUnion
     ) {
     }
 }
+
+class AbstractObjectNormalizerWithMetadataAndPropertyTypeExtractors extends AbstractObjectNormalizer
+{
+    public function __construct()
+    {
+        parent::__construct(new ClassMetadataFactory(new AttributeLoader()), null, new PropertyInfoExtractor([], [new PhpDocExtractor(), new ReflectionExtractor()]));
+    }
+
+    public function getSupportedTypes(?string $format): array
+    {
+        return ['*' => false];
+    }
+
+    protected function extractAttributes(object $object, ?string $format = null, array $context = []): array
+    {
+        return [];
+    }
+
+    protected function getAttributeValue(object $object, string $attribute, ?string $format = null, array $context = []): mixed
+    {
+        return null;
+    }
+
+    protected function setAttributeValue(object $object, string $attribute, $value, ?string $format = null, array $context = []): void
+    {
+        if (property_exists($object, $attribute)) {
+            $object->$attribute = $value;
+        }
+    }
+}
