@@ -1478,13 +1478,13 @@ EOT
 data: !!binary |
     SGVsbG8gd29ybGQ=
 EOT
-    ],
+            ],
             'containing spaces in block scalar' => [
                 <<<'EOT'
 data: !!binary |
     SGVs bG8gd 29ybGQ=
 EOT
-    ],
+            ],
         ];
     }
 
@@ -2971,6 +2971,11 @@ YAML;
         ], $this->parser->parse($expected));
     }
 
+    public function testSkipBlankLines()
+    {
+        $this->assertSame(['foo' => [null]], (new Parser())->parse("foo:\n-\n\n"));
+    }
+
     private function assertSameData($expected, $actual)
     {
         $this->assertEquals($expected, $actual);
